.. _demo:

#############
Demonstration
#############

Start with our :tf:variable:`Nice input variable <some-variable>`

See the generated :ref:`tf-definitionsindex`.

.. tf:resource:: foo_resource.baz

    Some documentation written from the RestructuredText file.

.. tf:resource:: foo_resource.markdown
    :markup: md

.. tf:data:: foo_data.qux

.. tf:variable:: some-variable

